@@ -1,14 +1,16 @@
+import warnings
+
 from django.conf import settings
 from django.core import validators
 from django.core.exceptions import ImproperlyConfigured
 from django.forms import Select, TextInput
 from django.forms.widgets import MultiWidget
 from django.utils import translation
-from phonenumbers import PhoneNumberFormat
-from phonenumbers.phonenumberutil import (
+from phonenumbers import (
     COUNTRY_CODE_TO_REGION_CODE,
     national_significant_number,
     region_code_for_number,
+    region_codes_for_country_code,
 )
 
 from phonenumber_field.phonenumber import PhoneNumber, to_python
@@ -16,7 +18,7 @@ from phonenumber_field.phonenumber import PhoneNumber, to_python
 try:
     import babel
 except ModuleNotFoundError:
-    babel = None
+    babel = None  # type: ignore
 
 # ISO 3166-1 alpha-2 to national prefix
 REGION_CODE_TO_COUNTRY_CODE = {
@@ -64,9 +66,10 @@ class PhonePrefixSelect(Select):
 
 class PhoneNumberPrefixWidget(MultiWidget):
     """
-    A Widget that splits phone number input into:
-    - a country select box for phone prefix
-    - an input for local phone number
+    A Widget that splits a phone number into fields:
+
+    - a :class:`~django.forms.Select` for the country (phone prefix)
+    - a :class:`~django.forms.TextInput` for local phone number
     """
 
     def __init__(
@@ -76,16 +79,29 @@ class PhoneNumberPrefixWidget(MultiWidget):
         country_attrs=None,
         country_choices=None,
         number_attrs=None,
+        region=None,
     ):
         """
-        :param country_choices: Limit the country choices.
+        :keyword dict attrs: See :attr:`~django.forms.Widget.attrs`
+        :keyword dict initial: See :attr:`~django.forms.Field.initial`
+        :keyword dict country_attrs: The :attr:`~django.forms.Widget.attrs` for
+            the country :class:`~django.forms.Select`.
+        :keyword country_choices: Limit the country choices.
         :type country_choices: list of 2-tuple, optional
             The first element is the value, which must match a country code
             recognized by the phonenumbers project.
             The second element is the label.
+        :keyword dict number_attrs: The :attr:`~django.forms.Widget.attrs` for
+            the local phone number :class:`~django.forms.TextInput`.
+        :keyword str region: 2-letter country code as defined in ISO 3166-1.
+            When not supplied, defaults to :setting:`PHONENUMBER_DEFAULT_REGION`
         """
         widgets = (
-            PhonePrefixSelect(initial, attrs=country_attrs, choices=country_choices),
+            PhonePrefixSelect(
+                initial or region,
+                attrs=country_attrs,
+                choices=country_choices,
+            ),
             TextInput(attrs=number_attrs),
         )
         super().__init__(widgets, attrs)
@@ -113,24 +129,57 @@ class PhoneNumberPrefixWidget(MultiWidget):
         return number
 
 
-class PhoneNumberInternationalFallbackWidget(TextInput):
+class RegionalPhoneNumberWidget(TextInput):
     """
-    A Widget that allows a phone number in a national format, but if given
-    an international number will fall back to international format
+    A :class:`~django.forms.Widget` that prefers displaying numbers in the
+    national format, and falls back to :setting:`PHONENUMBER_DEFAULT_FORMAT`
+    for international numbers.
     """
 
+    input_type = "tel"
+
     def __init__(self, region=None, attrs=None):
+        """
+        :keyword str region: 2-letter country code as defined in ISO 3166-1.
+            When not supplied, defaults to :setting:`PHONENUMBER_DEFAULT_REGION`
+        :keyword dict attrs: See :attr:`django.forms.Widget.attrs`
+        """
         if region is None:
             region = getattr(settings, "PHONENUMBER_DEFAULT_REGION", None)
         self.region = region
         super().__init__(attrs)
 
+    def value_from_datadict(self, data, files, name):
+        phone_number_str = super().value_from_datadict(data, files, name)
+
+        if phone_number_str is None:
+            phone_number_str = ""
+        return to_python(phone_number_str, region=self.region)
+
     def format_value(self, value):
         if isinstance(value, PhoneNumber):
-            number_region = region_code_for_number(value)
-            if self.region != number_region:
-                formatter = PhoneNumberFormat.INTERNATIONAL
-            else:
-                formatter = PhoneNumberFormat.NATIONAL
-            return value.format_as(formatter)
+            if value.is_valid() and value.country_code:
+                region_codes = region_codes_for_country_code(value.country_code)
+                if self.region in region_codes:
+                    return value.as_national
+        return super().format_value(value)
+
+
+class PhoneNumberInternationalFallbackWidget(RegionalPhoneNumberWidget):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        warnings.warn(
+            f"{self.__class__.__name__} will be removed in the next major version. "
+            "Use phonenumber_field.widgets.RegionalPhoneNumberWidget instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+
+    def format_value(self, value):
+        if isinstance(value, PhoneNumber):
+            if value.is_valid() and value.country_code:
+                region_codes = region_codes_for_country_code(value.country_code)
+                if self.region in region_codes:
+                    return value.as_national
+                return value.as_international
         return super().format_value(value)
