@@ -2,7 +2,7 @@ from django import forms
 
 from phonenumber_field.formfields import PhoneNumberField
 
-from .models import NullablePhoneNumber
+from .models import NullablePhoneNumber, TestModelRegionAR
 
 
 class PhoneNumberForm(forms.ModelForm):
@@ -13,3 +13,9 @@ class PhoneNumberForm(forms.ModelForm):
 
 class CustomPhoneNumberFormField(PhoneNumberField):
     pass
+
+
+class ARPhoneNumberForm(forms.ModelForm):
+    class Meta:
+        model = TestModelRegionAR
+        fields = ["phone"]
