@@ -8,7 +8,7 @@ class MandatoryPhoneNumber(models.Model):
 
 
 class OptionalPhoneNumber(models.Model):
-    phone_number = PhoneNumberField(blank=True, default="")
+    phone_number = PhoneNumberField(blank=True)
 
 
 class NullablePhoneNumber(models.Model):
@@ -29,42 +29,42 @@ class CustomPhoneNumber(models.Model):
 class TestModel(models.Model):
     """Basic Field Test"""
 
-    name = models.CharField(max_length=255, blank=True, default="")
+    name = models.CharField(max_length=255, blank=True)
     phone = PhoneNumberField()
 
 
 class TestModelPhoneB(models.Model):
     """Field Test for when Blank"""
 
-    name = models.CharField(max_length=255, blank=True, default="")
+    name = models.CharField(max_length=255, blank=True)
     phone = PhoneNumberField(blank=True)
 
 
 class TestModelPhoneNU(models.Model):
     """Field Test for when Null & Unique"""
 
-    name = models.CharField(max_length=255, blank=True, default="")
+    name = models.CharField(max_length=255, blank=True)
     phone = PhoneNumberField(null=True, unique=True)
 
 
 class TestModelPhoneBNU(models.Model):
     """Field Test for when Blank, Null & Unique"""
 
-    name = models.CharField(max_length=255, blank=True, default="")
+    name = models.CharField(max_length=255, blank=True)
     phone = PhoneNumberField(blank=True, null=True, unique=True)
 
 
 class TestModelPhoneNDNU(models.Model):
     """Field Test for when No Default, Null & Unique"""
 
-    name = models.CharField(max_length=255, blank=True, default="")
+    name = models.CharField(max_length=255, blank=True)
     phone = PhoneNumberField(default=models.NOT_PROVIDED, null=True, unique=True)
 
 
 class TestModelPhoneBNDNU(models.Model):
     """Field Test for when Blank, No Default, Null & Unique"""
 
-    name = models.CharField(max_length=255, blank=True, default="")
+    name = models.CharField(max_length=255, blank=True)
     phone = PhoneNumberField(
         blank=True, default=models.NOT_PROVIDED, null=True, unique=True
     )
@@ -73,28 +73,28 @@ class TestModelPhoneBNDNU(models.Model):
 class TestModelPhoneDNU(models.Model):
     """Field Test for when Default, Null & Unique"""
 
-    name = models.CharField(max_length=255, blank=True, default="")
+    name = models.CharField(max_length=255, blank=True)
     phone = PhoneNumberField(default="+41524242424", null=True, unique=True)
 
 
 class TestModelPhoneBDNU(models.Model):
     """Field Test for when Blank, Default, Null & Unique"""
 
-    name = models.CharField(max_length=255, blank=True, default="")
+    name = models.CharField(max_length=255, blank=True)
     phone = PhoneNumberField(blank=True, default="+41524242424", null=True, unique=True)
 
 
 class TestModelPhoneEDNU(models.Model):
     """Field Test for when Empty Default, Null & Unique"""
 
-    name = models.CharField(max_length=255, blank=True, default="")
+    name = models.CharField(max_length=255, blank=True)
     phone = PhoneNumberField(default="", null=True, unique=True)
 
 
 class TestModelPhoneBEDNU(models.Model):
     """Field Test for when Blank, Empty Default, Null & Unique"""
 
-    name = models.CharField(max_length=255, blank=True, default="")
+    name = models.CharField(max_length=255, blank=True)
     phone = PhoneNumberField(blank=True, default="", null=True, unique=True)
 
 
