@@ -1,3 +1,4 @@
+import django
 import phonenumbers
 from django import forms
 from django.core.exceptions import ImproperlyConfigured
@@ -9,6 +10,7 @@ from phonenumber_field.phonenumber import PhoneNumber
 from phonenumber_field.widgets import (
     PhoneNumberInternationalFallbackWidget,
     PhoneNumberPrefixWidget,
+    RegionalPhoneNumberWidget,
 )
 
 
@@ -29,6 +31,7 @@ class PhonePrefixSelectTest(SimpleTestCase):
 
 def example_number(region_code: str) -> PhoneNumber:
     number = phonenumbers.example_number(region_code)
+    assert number is not None
     e164 = phonenumbers.format_number(number, phonenumbers.PhoneNumberFormat.E164)
     return PhoneNumber.from_string(e164, region=region_code)
 
@@ -64,6 +67,11 @@ class PhoneNumberPrefixWidgetTest(SimpleTestCase):
         self.assertIn('<option value="">---------</option>', rendered)
         self.assertIn('<option value="CN" selected>China +86</option>', rendered)
 
+    def test_uses_kwarg_region_as_prefix(self):
+        rendered = PhoneNumberPrefixWidget(region="CN").render("", "")
+        self.assertIn('<option value="">---------</option>', rendered)
+        self.assertIn('<option value="CN" selected>China +86</option>', rendered)
+
     def test_no_initial(self):
         rendered = PhoneNumberPrefixWidget().render("", "")
         self.assertIn('<option value="" selected>---------</option>', rendered)
@@ -105,10 +113,12 @@ class PhoneNumberPrefixWidgetTest(SimpleTestCase):
             "(e.g. +12125552368).</li></ul>",
             rendered_form,
         )
+        aria_invalid = "" if django.VERSION[0] < 5 else 'aria-invalid="true" '
         # Keeps national number input.
         self.assertInHTML(
-            f'<input type="text" name="phone_1" '
-            f'value="{invalid_national_number}" required id="id_phone_1">',
+            '<input type="text" name="phone_1" '
+            f'value="{invalid_national_number}" {aria_invalid} required '
+            'id="id_phone_1">',
             rendered_form,
             count=1,
         )
@@ -126,8 +136,10 @@ class PhoneNumberPrefixWidgetTest(SimpleTestCase):
             '<ul class="errorlist"><li>This field is required.</li></ul>',
             rendered_form,
         )
+        aria_invalid = "" if django.VERSION[0] < 5 else 'aria-invalid="true" '
         self.assertInHTML(
-            '<input type="text" name="phone_1" required id="id_phone_1">',
+            f'<input type="text" name="phone_1" {aria_invalid} '
+            'required id="id_phone_1">',
             rendered_form,
             count=1,
         )
@@ -150,8 +162,9 @@ class PhoneNumberPrefixWidgetTest(SimpleTestCase):
             "(e.g. +12125552368).</li></ul>",
             rendered_form,
         )
+        aria_invalid = "" if django.VERSION[0] < 5 else 'aria-invalid="true" '
         self.assertInHTML(
-            '<input type="text" name="phone_1" value="654321" '
+            f'<input type="text" name="phone_1" value="654321" {aria_invalid} '
             'required id="id_phone_1">',
             rendered_form,
             count=1,
@@ -171,8 +184,10 @@ class PhoneNumberPrefixWidgetTest(SimpleTestCase):
             rendered_form,
             count=1,
         )
+        aria_invalid = "" if django.VERSION[0] < 5 else 'aria-invalid="true" '
         self.assertInHTML(
-            '<input type="text" name="phone_1" required id="id_phone_1">',
+            f'<input type="text" name="phone_1" {aria_invalid} '
+            'required id="id_phone_1">',
             rendered_form,
             count=1,
         )
@@ -195,8 +210,10 @@ class PhoneNumberPrefixWidgetTest(SimpleTestCase):
             "</li></ul>",
             rendered_form,
         )
+        aria_invalid = "" if django.VERSION[0] < 5 else 'aria-invalid="true" '
         self.assertInHTML(
-            '<input type="text" name="phone_1" value="0000" required id="id_phone_1">',
+            f'<input type="text" name="phone_1" value="0000" {aria_invalid} '
+            'required id="id_phone_1">',
             rendered_form,
             count=1,
         )
@@ -239,24 +256,98 @@ class PhoneNumberPrefixWidgetTest(SimpleTestCase):
         )
 
 
-class PhoneNumberInternationalFallbackWidgetTest(SimpleTestCase):
+class RegionalPhoneNumberWidgetTest(SimpleTestCase):
+    @override_settings(PHONENUMBER_DEFAULT_FORMAT="INTERNATIONAL")
     def test_fallback_widget_switches_between_national_and_international(self):
         region = "GB"
         number_string = "01606 751 78"
         number = PhoneNumber.from_string(number_string, region=region)
-        gb_widget = PhoneNumberInternationalFallbackWidget(region="GB")
-        de_widget = PhoneNumberInternationalFallbackWidget(region="DE")
+        gb_widget = RegionalPhoneNumberWidget()
+        gb_widget.region = "GB"
+        de_widget = RegionalPhoneNumberWidget()
+        de_widget.region = "DE"
         self.assertHTMLEqual(
             gb_widget.render("number", number),
-            '<input name="number" type="text" value="01606 75178" />',
+            '<input name="number" type="tel" value="01606 75178" />',
         )
         self.assertHTMLEqual(
             de_widget.render("number", number),
-            '<input name="number" type="text" value="+44 1606 75178" />',
+            '<input name="number" type="tel" value="+44 1606 75178" />',
         )
 
         # If there's been a validation error, the value should be included verbatim
         self.assertHTMLEqual(
             gb_widget.render("number", "error"),
-            '<input name="number" type="text" value="error" />',
+            '<input name="number" type="tel" value="error" />',
+        )
+
+    def test_fallback_defaults_to_phonenumber_default_format(self):
+        region = "GB"
+        number_string = "01606 751 78"
+        number = PhoneNumber.from_string(number_string, region=region)
+        widget = RegionalPhoneNumberWidget(region="FR")
+        for fmt, expected in [
+            ("INTERNATIONAL", "+44 1606 75178"),
+            ("E164", "+44160675178"),
+            ("RFC3966", "tel:+44-1606-75178"),
+        ]:
+            with self.subTest(fmt):
+                with override_settings(PHONENUMBER_DEFAULT_FORMAT=fmt):
+                    self.assertHTMLEqual(
+                        widget.render("number", number),
+                        f'<input name="number" type="tel" value="{expected}" />',
+                    )
+
+    def test_no_region(self):
+        number_string = "+33612345678"
+        number = PhoneNumber.from_string(number_string)
+        widget = RegionalPhoneNumberWidget()
+        for fmt, expected in [
+            ("INTERNATIONAL", "+33 6 12 34 56 78"),
+            ("E164", "+33612345678"),
+            ("RFC3966", "tel:+33-6-12-34-56-78"),
+        ]:
+            with self.subTest(fmt):
+                with override_settings(PHONENUMBER_DEFAULT_FORMAT=fmt):
+                    self.assertHTMLEqual(
+                        widget.render("number", number),
+                        f'<input name="number" type="tel" value="{expected}" />',
+                    )
+
+
+class PhoneNumberInternationalFallbackWidgetTest(SimpleTestCase):
+    def test_raises_deprecation_warning(self):
+        msg = (
+            "PhoneNumberInternationalFallbackWidget will be removed in the next major "
+            "version. Use phonenumber_field.widgets.RegionalPhoneNumberWidget "
+            "instead."
+        )
+        with self.assertWarnsMessage(DeprecationWarning, msg):
+
+            class _(forms.Form):
+                number = formfields.PhoneNumberField(
+                    widget=PhoneNumberInternationalFallbackWidget
+                )
+
+    def test_fallback_widget_switches_between_national_and_international(self):
+        region = "GB"
+        number_string = "01606 751 78"
+        number = PhoneNumber.from_string(number_string, region=region)
+        gb_widget = PhoneNumberInternationalFallbackWidget()
+        gb_widget.region = "GB"
+        de_widget = PhoneNumberInternationalFallbackWidget()
+        de_widget.region = "DE"
+        self.assertHTMLEqual(
+            gb_widget.render("number", number),
+            '<input name="number" type="tel" value="01606 75178" />',
+        )
+        self.assertHTMLEqual(
+            de_widget.render("number", number),
+            '<input name="number" type="tel" value="+44 1606 75178" />',
+        )
+
+        # If there's been a validation error, the value should be included verbatim
+        self.assertHTMLEqual(
+            gb_widget.render("number", "error"),
+            '<input name="number" type="tel" value="error" />',
         )
