@@ -1,10 +1,10 @@
+import django
 import phonenumbers
 from django import forms
 from django.core import checks
 from django.db.models import Model
 from django.test import SimpleTestCase, TestCase, override_settings
 from django.utils.encoding import force_str
-from phonenumbers import phonenumberutil
 
 from phonenumber_field import formfields, modelfields
 from phonenumber_field.phonenumber import PhoneNumber, to_python
@@ -129,9 +129,7 @@ class PhoneNumberFieldTestCase(TestCase):
         self.assertIsNone(model.phone_number)
         model.phone_number = self.test_number_1
         self.assertIsInstance(model.phone_number, PhoneNumber)
-        model.phone_number = phonenumberutil.parse(
-            self.test_number_1, keep_raw_input=True
-        )
+        model.phone_number = phonenumbers.parse(self.test_number_1, keep_raw_input=True)
         self.assertIsInstance(model.phone_number, PhoneNumber)
 
     def test_can_assign_string_phone_number(self):
@@ -149,10 +147,10 @@ class PhoneNumberFieldTestCase(TestCase):
 
     def test_can_assign_phonenumber(self):
         """
-        Tests assignment phonenumberutil.PhoneNumber to field
+        Tests assignment phonenumbers.PhoneNumber to field
         """
         opt_phone = models.OptionalPhoneNumber()
-        opt_phone.phone_number = phonenumberutil.parse(
+        opt_phone.phone_number = phonenumbers.parse(
             self.test_number_1, keep_raw_input=True
         )
         self.assertIsInstance(opt_phone.phone_number, PhoneNumber)
@@ -258,8 +256,50 @@ class PhoneNumberFieldTestCase(TestCase):
             1,
         )
 
+    def test_values_list(self):
+        num0 = "+33600000000"
+        num1 = "+33611111111"
+        models.MandatoryPhoneNumber.objects.bulk_create(
+            [
+                models.MandatoryPhoneNumber(phone_number=num0),
+                models.MandatoryPhoneNumber(phone_number=num1),
+            ]
+        )
+        number0, number1 = models.MandatoryPhoneNumber.objects.order_by(
+            "phone_number"
+        ).values_list("phone_number", flat=True)
+        self.assertIsInstance(number0, PhoneNumber)
+        self.assertEqual(to_python(num0), number0)
+        self.assertIsInstance(number1, PhoneNumber)
+        self.assertEqual(to_python(num1), number1)
+
+    def test_values_with_null(self):
+        num0 = "+33600000000"
+        models.NullablePhoneNumber.objects.bulk_create(
+            [
+                models.NullablePhoneNumber(phone_number=num0),
+                models.NullablePhoneNumber(phone_number=""),
+                models.NullablePhoneNumber(phone_number=None),
+            ]
+        )
+        number0, number1, number2 = models.NullablePhoneNumber.objects.order_by(
+            "pk"
+        ).values_list("phone_number", flat=True)
+        self.assertIsInstance(number0, PhoneNumber)
+        self.assertEqual(to_python(num0), number0)
+        self.assertIsInstance(number1, str)
+        self.assertEqual(number1, "")
+        self.assertIsNone(number2)
+
 
 class PhoneNumberFieldAppTest(TestCase):
+    @classmethod
+    def setUpClass(cls):
+        super().setUpClass()
+        # Drop alias with support for Django 3.2.
+        if django.VERSION < (4, 2):
+            cls.assertQuerySetEqual = cls.assertQuerysetEqual
+
     def test_save_field_to_database(self):
         """Basic Field Test"""
         tm = models.TestModel()
@@ -270,7 +310,7 @@ class PhoneNumberFieldAppTest(TestCase):
 
         tm = models.TestModel.objects.get(pk=pk)
         self.assertIsInstance(tm.phone, PhoneNumber)
-        self.assertQuerysetEqual(
+        self.assertQuerySetEqual(
             models.TestModel.objects.all(),
             [(tm.pk, "", "+41524242424")],
             transform=phone_transform,
@@ -310,7 +350,7 @@ class PhoneNumberFieldAppTest(TestCase):
 
         pk = tm.id
         tm = models.TestModelPhoneB.objects.get(pk=pk)
-        self.assertQuerysetEqual(
+        self.assertQuerySetEqual(
             models.TestModelPhoneB.objects.all(),
             [(tm.pk, "", "")],
             transform=phone_transform,
@@ -324,7 +364,7 @@ class PhoneNumberFieldAppTest(TestCase):
         pk = tm.id
         tm = TestModel.objects.get(pk=pk)
         self.assertIsNone(tm.phone)
-        self.assertQuerysetEqual(
+        self.assertQuerySetEqual(
             TestModel.objects.all(), [(tm.pk, "", None)], transform=phone_transform
         )
 
@@ -355,7 +395,7 @@ class PhoneNumberFieldAppTest(TestCase):
 
         pk = tm.id
         tm = TestModel.objects.get(pk=pk)
-        self.assertQuerysetEqual(
+        self.assertQuerySetEqual(
             TestModel.objects.all(),
             [(tm.pk, "", "+41524242424")],
             transform=phone_transform,
@@ -376,7 +416,7 @@ class PhoneNumberFieldAppTest(TestCase):
 
         pk = tm.id
         tm = TestModel.objects.get(pk=pk)
-        self.assertQuerysetEqual(
+        self.assertQuerySetEqual(
             TestModel.objects.all(), [(tm.pk, "", "")], transform=phone_transform
         )
 
@@ -626,6 +666,7 @@ class RegionPhoneNumberModelFieldTest(TestCase):
     def test_region_field_renders_invalid_numbers(self):
         form = ARPhoneNumberForm({"phone": "abcdef"})
         self.assertFalse(form.is_valid())
+        aria_invalid = "" if django.VERSION[0] < 5 else 'aria-invalid="true" '
         self.assertHTMLEqual(
             form.as_p(),
             '<ul class="errorlist">'
@@ -639,6 +680,7 @@ class RegionPhoneNumberModelFieldTest(TestCase):
             'name="phone" '
             'value="abcdef" '
             'maxlength="128" '
+            f"{aria_invalid}"
             'id="id_phone">'
             "</p>",
         )
